#pragma once
/*++

Copyright (c) Pico Systems Co., Ltd.

Module Name: bvcm.h

Abstract:

	Support Library for MDB-MIF-01
	MDB-IF Dynamic Link library definitions

Revision History:

	27/Jan/2020   Created by Makoto Ito

--*/
#pragma once  

#include "windows.h"


// The following ifdef block is the standard way of creating macros
// which make exporting from a DLL simpler.

#ifdef MDB_IF_DLL_EXPORTS
#define MDB_IF_API __declspec(dllexport)   
#else  
#define MDB_IF_API __declspec(dllimport)   
#endif  

// Type Definition

typedef HANDLE	MDB_IF_HANDLE;
typedef ULONG	MDB_IF_STATUS;

// Device status

enum
{
	MDB_IF_OK,
	MDB_IF_INVALID_HANDLE,
	MDB_IF_IO_ERROR,
	MDB_IF_INVALID_PARAMETER,
	MDB_IF_NO_RESPONSE,
	MDB_IF_OTHER_ERROR,
	MDB_IF_NG,
	MDB_IF_BUSY
};

// Etc.

#define STX			0x02
#define ETX			0x03
#define CR			0x0D
#define ESC			0x7D
#define ESC_STX		0xE2
#define ESC_ETX		0xE3
#define ESC_ESC		0x5D

#define HOST_ADRES	0x00
#define MDB_IF_ADRS	0x30

#define MAX_MDB_PACKET_SIZE	36

// Functions to Export

MDB_IF_API
MDB_IF_STATUS WINAPI MDB_IF_ScanInterface
(
	LPSTR psComPort
);

MDB_IF_API
MDB_IF_STATUS WINAPI MDB_IF_OpenInterface
(
	LPSTR psComPort,
	MDB_IF_HANDLE* mdbIfHandle
);

MDB_IF_API
MDB_IF_STATUS WINAPI MDB_IF_CloseInterface
(
	MDB_IF_HANDLE mdbIfHandle
);

MDB_IF_API
MDB_IF_STATUS WINAPI MDB_IF_ExecCommand
(
	MDB_IF_HANDLE mdbIfHandle,
	unsigned char* pucCommand,
	int iCommandLength,
	unsigned char* pucReceiveBuffer,
	int* piReceiveBufferSize
);

MDB_IF_API
MDB_IF_STATUS WINAPI MDB_IF_LineReset
(
	MDB_IF_HANDLE mdbIfHandle
);

MDB_IF_API
MDB_IF_STATUS WINAPI MDB_IF_GetVersion
(
	MDB_IF_HANDLE mdbIfHandle,
	unsigned char* pucBuffer,
	unsigned int uiBufferSize
);
